==> blesta-5.10.2.zip: blesta/language/ru_ru/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Неверный формат конечной даты.';
$lang['Logs.!error.start_date.format'] = 'Неверный формат начальной даты.';
$lang['Logs.!error.group.betweenlength'] = 'Длина группы должна составлять от 1 до 32 символов.';
$lang['Logs.!error.group.unique'] = 'Идентификатор задачи cron и группа уже заняты.';
$lang['Logs.!error.event.maxlength'] = 'Длина события не должна превышать 32 символов.';
$lang['Logs.!error.run_id.exists'] = 'Неверный идентификатор задачи cron.';
$lang['Logs.!error.last_name.empty'] = 'Фамилия не должна быть пустой.';
$lang['Logs.!error.first_name.empty'] = 'Имя и фамилия не должны быть пустыми.';
$lang['Logs.!error.account_id.empty'] = 'Отсутствует идентификатор учетной записи.';
$lang['Logs.!error.account_type.format'] = 'Неверный тип счета.';
$lang['Logs.!error.type.format'] = 'Неверный тип.';
$lang['Logs.!error.staff_id.empty'] = 'Пропал идентификатор сотрудника.';
$lang['Logs.!error.date_changed.valid'] = 'Неверная дата изменена.';
$lang['Logs.!error.by_user_id.exists'] = 'Недействительно по идентификатору пользователя.';
$lang['Logs.!error.fields.empty'] = 'Отсутствуют поля, которые можно регистрировать.';
$lang['Logs.!error.client_id.exists'] = 'Неверный идентификатор клиента.';
$lang['Logs.!error.contact_id.empty'] = 'Идентификатор отсутствующего контакта.';
$lang['Logs.!error.success.format'] = 'Недопустимое значение успеха.';
$lang['Logs.!error.messenger_id.exists'] = 'Неверный идентификатор мессенджера.';
$lang['Logs.!error.to_user_id.exists'] = 'Неверный идентификатор пользователя.';
$lang['Logs.!error.result.format'] = 'Результатом входа в систему должно быть либо "успех", либо "провал".';
$lang['Logs.!error.user_log_exists.empty'] = 'Пользователь с указанным IP-адресом не существует.';
$lang['Logs.!error.ip_address.length'] = 'Длина IP-адреса не должна превышать 39 символов.';
$lang['Logs.!error.ip_address.empty'] = 'Отсутствует IP-адрес.';
$lang['Logs.!error.user_id.empty'] = 'Отсутствует идентификатор пользователя.';
$lang['Logs.!error.group.maxlength'] = 'Длина группы не должна превышать 8 символов.';
$lang['Logs.!error.group.empty'] = 'Отсутствующая группа.';
$lang['Logs.!error.status.format'] = 'Недопустимый тип состояния.';
$lang['Logs.!error.url.empty'] = 'Отсутствующий URL.';
$lang['Logs.!error.direction.format'] = 'Недопустимый тип направления.';
$lang['Logs.!error.gateway_id.exists'] = 'Неверный идентификатор шлюза.';
$lang['Logs.!error.module_id.exists'] = 'Неверный идентификатор модуля.';
$lang['Logs.!error.staff_id.exists'] = 'Неверный идентификатор сотрудника.';
$lang['Logs.!error.sent.length'] = 'Длина сообщения не должна превышать 1 символа.';
$lang['Logs.!error.sent.format'] = 'Отправлено должно быть числом.';
$lang['Logs.!error.subject.empty'] = 'Отсутствие предмета.';
$lang['Logs.!error.from_name.empty'] = 'Не хватает имени.';
$lang['Logs.!error.from_address.empty'] = 'Не хватает адреса.';
$lang['Logs.!error.to_address.empty'] = 'Не хватает "а" для адреса.';
$lang['Logs.!error.company_id.exists'] = 'Неверный идентификатор компании.';
$lang['Logs.!error.deletelog_datetime'] = 'Неверный формат даты.';

==> blesta-5.11.4.zip: blesta/language/ru_ru/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Неверный формат конечной даты.';
$lang['Logs.!error.start_date.format'] = 'Неверный формат начальной даты.';
$lang['Logs.!error.group.betweenlength'] = 'Длина группы должна составлять от 1 до 32 символов.';
$lang['Logs.!error.group.unique'] = 'Идентификатор задачи cron и группа уже заняты.';
$lang['Logs.!error.event.maxlength'] = 'Длина события не должна превышать 32 символов.';
$lang['Logs.!error.run_id.exists'] = 'Неверный идентификатор задачи cron.';
$lang['Logs.!error.last_name.empty'] = 'Фамилия не должна быть пустой.';
$lang['Logs.!error.first_name.empty'] = 'Имя и фамилия не должны быть пустыми.';
$lang['Logs.!error.account_id.empty'] = 'Отсутствует идентификатор учетной записи.';
$lang['Logs.!error.account_type.format'] = 'Неверный тип счета.';
$lang['Logs.!error.type.format'] = 'Неверный тип.';
$lang['Logs.!error.staff_id.empty'] = 'Пропал идентификатор сотрудника.';
$lang['Logs.!error.date_changed.valid'] = 'Неверная дата изменена.';
$lang['Logs.!error.by_user_id.exists'] = 'Недействительно по идентификатору пользователя.';
$lang['Logs.!error.fields.empty'] = 'Отсутствуют поля, которые можно регистрировать.';
$lang['Logs.!error.client_id.exists'] = 'Неверный идентификатор клиента.';
$lang['Logs.!error.contact_id.empty'] = 'Идентификатор отсутствующего контакта.';
$lang['Logs.!error.success.format'] = 'Недопустимое значение успеха.';
$lang['Logs.!error.messenger_id.exists'] = 'Неверный идентификатор мессенджера.';
$lang['Logs.!error.to_user_id.exists'] = 'Неверный идентификатор пользователя.';
$lang['Logs.!error.result.format'] = 'Результатом входа в систему должно быть либо "успех", либо "провал".';
$lang['Logs.!error.user_log_exists.empty'] = 'Пользователь с указанным IP-адресом не существует.';
$lang['Logs.!error.ip_address.length'] = 'Длина IP-адреса не должна превышать 39 символов.';
$lang['Logs.!error.ip_address.empty'] = 'Отсутствует IP-адрес.';
$lang['Logs.!error.user_id.empty'] = 'Отсутствует идентификатор пользователя.';
$lang['Logs.!error.group.maxlength'] = 'Длина группы не должна превышать 8 символов.';
$lang['Logs.!error.group.empty'] = 'Отсутствующая группа.';
$lang['Logs.!error.status.format'] = 'Недопустимый тип состояния.';
$lang['Logs.!error.url.empty'] = 'Отсутствующий URL.';
$lang['Logs.!error.direction.format'] = 'Недопустимый тип направления.';
$lang['Logs.!error.gateway_id.exists'] = 'Неверный идентификатор шлюза.';
$lang['Logs.!error.module_id.exists'] = 'Неверный идентификатор модуля.';
$lang['Logs.!error.staff_id.exists'] = 'Неверный идентификатор сотрудника.';
$lang['Logs.!error.sent.length'] = 'Длина сообщения не должна превышать 1 символа.';
$lang['Logs.!error.sent.format'] = 'Отправлено должно быть числом.';
$lang['Logs.!error.subject.empty'] = 'Отсутствие предмета.';
$lang['Logs.!error.from_name.empty'] = 'Не хватает имени.';
$lang['Logs.!error.from_address.empty'] = 'Не хватает адреса.';
$lang['Logs.!error.to_address.empty'] = 'Не хватает "а" для адреса.';
$lang['Logs.!error.company_id.exists'] = 'Неверный идентификатор компании.';
$lang['Logs.!error.deletelog_datetime'] = 'Неверный формат даты.';
$lang['Logs.!error.new_service.format'] = 'Новая служба должна представлять собой массив.';
$lang['Logs.!error.old_service.format'] = 'Старый сервис должен быть массивом.';
$lang['Logs.!error.transactions.exists'] = 'Одна или несколько транзакций не существует.';
$lang['Logs.!error.transaction_id.format'] = 'Транзакции должны быть массивом.';
$lang['Logs.!error.service_id.exists'] = 'Неверный идентификатор службы.';
